# mlsgrid_api - Python library for the MLSGrid API
This library provides a wrapper and convenience functions for the [MLSGrid](https://www.mlsgrid.com/) Multiple Listing Service database replication API.  

Documentation on the API itself can be found [here](https://docs.mlsgrid.com/api-documentation/api-version-2.0).